# Question Answering

The `QuestionAnswering` task answers questions based on the content of the documents.

## Usage

```python
--8<-- "sieves/tests/docs/test_task_usage.py:qa-usage"
```

---

::: sieves.tasks.predictive.question_answering.core
::: sieves.tasks.predictive.question_answering.bridges
